.. _glossary:

Glossary
########

This page lists definitions for terms used in the Open Data Cube and this manual.

.. glossary::
   :sorted:

   AGDC
   Australian Geoscience Data Cube
      An Australian project that developed the python library that became :term:`ODC`.

   API
   Application Programming Interface
      The Data Cube Application Programming Interface gives programmers full
      access to the capabilities of the Cube, allowing query and advanced data
      retrieval.
   
   CEOS-SEO
   Committee on Earth Observation, Systems Engineering Office
      Another group of developers working on ODC

   CRS
   Coordinate Reference System
      Specifies how a set of coordinates relates to a point on the earth.

   CSIRO
   Commonwealth Scientific and Industrial Research Organisation
      An Australian research agency participating in development of ODC


   DEA
   Digital Earth Australia

      Geoscience Australia's deployment of ODC, hosted at the :term:`NCI`. See
      the `DEA user guide <http://geoscienceaustralia.github.io/digitalearthau/>`_ for
      details on how to access the platform.

   GA
   Geoscience Australia
      The primary public sector geoscience organisation in Australia.
      It supports ODC through the development of Digital Earth Australia. For more
      information see http://www.ga.gov.au/dea/.

   grid spec
   Grid Specification
      A definition of how some raster data relates to a geospatial grid. Includes a CRS, a zero point, and an X and Y scale.

   NCI
   National Computation Infrastructure

      Australia's national research computing facility. It provides computing
      facilities for use by Australian researchers, industry and government. For
      more information see http://nci.org.au/.

   HPC
   High Performance Computing
      A supercomputer. These days typically a cluster
      of high performance computers linked together with high speed networking.

   Landsat
      A series of US owned earth observation satellites, with freely available data.

   MODIS
      US owned earth observation satellites with freely available data.

   ODC
   Open Data Cube

      Software for storing, managing and accessing Earth Observation data, and
      the community formed to further it's development.

   OGC
   Open Geospatial Consortium
      `Open Geospatial Consortium <http://www.opengeospatial.org>`_. An organisation which
      makes geospatial standards, especially relating to web services.

   PostgreSQL
      The high performance database engine used as an index of Datasets by the
      Data Cube. It is both a relational and document database, and the Data
      Cube schema makes use of both of these capabilities.

   Python
      The programming language used to develop the Data Cube. It is easy to use
      while still allowing high performance access and processing capabilities.
      See https://www.python.org/ for more.

   USGS
   United States Geological Survey
      The USA government organisation which operates both the Landsat and MODIS satellites,
      which are available as free an open earth observation data. 
      
   VDI
   Virtual Desktop Infrastructure
      A virtual desktop environment at NCI that provides a linux desktop
      environment for scientific computing. For more see
      http://vdi.nci.org.au/help.

   WMS
   Web Map Service
      A standard for delivery published maps into web browsers and
      GIS software, defined by the :term:`OGC`.

   YAML
   Yet Another Markup Language
      A human friendly data serialization standard for all programming
      languages. It is used for all on disk metadata files and product
      definitions in the Data Cube.

      For more information on the YAML standard see http://yaml.org/.

